@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "otpp" "3.4.1"
+(define-package "otpp" "20250909.2023"
   "One tab per project, with unique names."
   '((emacs  "28.1")
     (compat "29.1"))
   :url "https://github.com/abougouffa/one-tab-per-project"
-  :commit "2c5bfb6ef06d27a9589394339dadb856580a5a84"
-  :revdesc "2c5bfb6ef06d"
+  :commit "fb8e72b924013443ba810ad5347d6ca39f005158"
+  :revdesc "fb8e72b92401"
   :keywords '("convenience")
   :authors '(("Abdelhak Bougouffa (rot13" . "\"nobhtbhssn@srqbencebwrpg.bet\")"))
   :maintainers '(("Abdelhak Bougouffa (rot13" . "\"nobhtbhssn@srqbencebwrpg.bet\")")))
